[−][src]Struct vault_rs::sys::mounts::SecretsEngineTune
Tuning options for secrets engines
Fields
description: Option<String>Specifies the human-friendly description of the mount.
default_lease_ttl: Option<u64>The default lease duration, specified as a string duration like "5s" or "30m".
max_lease_ttl: Option<u64>The maximum lease duration, specified as a string duration like "5s" or "30m".
audit_non_hmac_request_keys: Option<HashSet<String>>List of keys that will not be HMAC'd by audit devices in the request data object.
audit_non_hmac_response_keys: Option<HashSet<String>>List of keys that will not be HMAC'd by audit devices in the response data object.
listing_visibility: Option<ListingVisibility>Specifies whether to show this mount in the UI-specific listing endpoint.
passthrough_request_headers: Option<HashSet<String>>List of headers to whitelist and pass from the request to the plugin.
allowed_response_headers: Option<HashSet<String>>List of headers to whitelist, allowing a plugin to include them in the response.